package com.cecilia.common.base;

import lombok.Data;

import java.util.HashMap;
import java.util.Map;

@Data
public class RuntimeErrorException extends RuntimeException {
    private static final long serialVersionUID = 2326809448876379756L;
    private Severity severity;
    private String errorScope;
    private int errorCode;
    private Map<String, Object> errorMap;

    public RuntimeErrorException() {
        this.severity = Severity.Error;
        this.errorCode = -1;
        this.errorMap = new HashMap();
    }

    public RuntimeErrorException(String message) {
        super(message);
        this.severity = Severity.Error;
        this.errorCode = -1;
        this.errorMap = new HashMap();
    }

    public RuntimeErrorException(String message, Throwable cause) {
        super(message, cause);
        this.severity = Severity.Error;
        this.errorCode = -1;
        this.errorMap = new HashMap();
    }

    public RuntimeErrorException(Throwable cause) {
        super(cause);
        this.severity = Severity.Error;
        this.errorCode = -1;
        this.errorMap = new HashMap();
    }

    public Throwable fillInStackTrace() {
        return this;
    }

    public RuntimeErrorException setSeverity(Severity severity) {
        this.severity = severity;
        return this;
    }

    public Severity getSeverity() {
        return this.severity;
    }

    public RuntimeErrorException setErrorScope(String errorScope) {
        this.errorScope = errorScope;
        return this;
    }

    public String getErrorScope() {
        return this.errorScope;
    }

    public RuntimeErrorException setErrorCode(int errorCode) {
        this.errorCode = errorCode;
        return this;
    }

    public int getErrorCode() {
        return this.errorCode;
    }

    public RuntimeErrorException setErrorObject(int index, Object obj) {
        this.errorMap.put(String.valueOf(index), obj);
        return this;
    }

    public Object getErrorObject(int index) {
        return this.errorMap.get(String.valueOf(index));
    }

    public RuntimeErrorException setErrorObject(String name, Object obj) {
        this.errorMap.put(name, obj);
        return this;
    }

    public Object getErrorObject(String name) {
        return this.errorMap.get(name);
    }

    public static RuntimeErrorException errorWith(String errorScope, int errorCode, String description, Object... errorObjects) {
        String errorMessage = String.format(description, errorObjects);
        RuntimeErrorException e = new RuntimeErrorException(errorMessage);
        e.setErrorScope(errorScope).setErrorCode(errorCode);
        if (errorObjects != null) {
            int i = 0;
            Object[] var7 = errorObjects;
            int var8 = errorObjects.length;

            for(int var9 = 0; var9 < var8; ++var9) {
                Object obj = var7[var9];
                e.setErrorObject(i, obj);
                ++i;
            }
        }

        return e;
    }

    public static RuntimeErrorException errorWith(Throwable cause, String errorScope, int errorCode, String description, Object... errorObjects) {
        String errorMessage = String.format(description, errorObjects);
        RuntimeErrorException e = new RuntimeErrorException(errorMessage, cause);
        e.setErrorScope(errorScope).setErrorCode(errorCode);
        if (errorObjects != null) {
            int i = 0;
            Object[] var8 = errorObjects;
            int var9 = errorObjects.length;

            for(int var10 = 0; var10 < var9; ++var10) {
                Object obj = var8[var10];
                e.setErrorObject(i, obj);
                ++i;
            }
        }

        return e;
    }

    public static enum Severity {
        Error,
        Fatal;

        private Severity() {
        }
    }
}
